This is a library for Image Processing to assist in Image Classification
I'm not entirely sure exactly what all this library will contain just yet,
but convolusions will be a main focus of it
It will use my Parallel Linear library under the hood for calculations
